##############################################################################
#
# MODULE:       r.slope.stability.install.sh
#
# AUTHOR:       Martin Mergili
#
# PURPOSE:      The slope stability model - Installation script
#
# COPYRIGHT:    (c) 2009 - 2015 by the author
#               (c) 2009 - 2015 by the BOKU University, Vienna
#               (c) 2015        by the University of Vienna
#               (c) 2000 - 2015 by the GRASS Development Team
#
# VERSION:      20150603 (3 June 2015)
#
#               This program is free software under the GNU General Public
#               License (>=v2). Read the file COPYING that comes with GRASS
#               for details.
#
##############################################################################


pathmain=`pwd`

PATHSOURCE="/usr/local/src/releasebranch_7_0/"
PATHGRASS="/usr/local/grass-7.0.2svn/"
PATHPYTHON="/usr/lib/python2.7/"

#echo "Full path to GRASS source (slashes at beginning and end): "
#read PATHSOURCE

#echo "Full path to GRASS installation (slashes at beginning and end): "
#read PATHGRASS

#echo "Full path to Python installation (slashes at beginning and end): "
#read PATHPYTHON


#INSTALLING R- AND PYTHON-BASED MODULES FOR DATA MANAGEMENT
#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Installing R scripts
cp r.slope.stability.evolution.r "$PATHGRASS"scripts/r.slope.stability.evolution.r
cp r.slope.stability.map.r "$PATHGRASS"scripts/r.slope.stability.map.r
cp r.slope.stability.profile.r "$PATHGRASS"scripts/r.slope.stability.profile.r
cp r.slope.stability.rad.r "$PATHGRASS"scripts/r.slope.stability.rad.r
cp r.slope.stability.reg.r "$PATHGRASS"scripts/r.slope.stability.reg.r
cp r.slope.stability.roc.r "$PATHGRASS"scripts/r.slope.stability.roc.r

#r.slope.stability.py is installed as module r.slope.stability
#Making python script executable
chmod +x r.slope.stability.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.slope.stability ]
then
    rm -rf "$PATHSOURCE"scripts/r.slope.stability
fi

#Creating directory for installation files, copying r.slope.stability.py and r.slope.stability.html
mkdir "$PATHSOURCE"scripts/r.slope.stability
cp r.slope.stability.py "$PATHSOURCE"scripts/r.slope.stability/r.slope.stability.py
cp r.slope.stability.html "$PATHSOURCE"scripts/r.slope.stability/r.slope.stability.html

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.slope.stability

# Creating help file and makefile
touch r.slope.stability.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.slope.stability" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.slope.stability
make
make install

cd $pathmain

#r.slope.stability.mult.py is installed as module r.slope.stability.mult
#Making python script executable
chmod +x r.slope.stability.mult.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.slope.stability.mult ]
then
    rm -rf "$PATHSOURCE"scripts/r.slope.stability.mult
fi

#Creating directory for installation files, copying r.slope.stability.mult.py
mkdir "$PATHSOURCE"scripts/r.slope.stability.mult
cp r.slope.stability.mult.py "$PATHSOURCE"scripts/r.slope.stability.mult/r.slope.stability.mult.py
cp r.slope.stability.html "$PATHSOURCE"scripts/r.slope.stability.mult/r.slope.stability.mult.html

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.slope.stability.mult

# Creating help file and makefile
touch r.slope.stability.mult.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.slope.stability.mult" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.slope.stability.mult
make
make install

echo ""
echo "Installation of r.slope.stability and associated scripts completed. Please check for possible error messages. "
echo "Press ENTER for proceeding with the installation of r.slope.stability.main. "
read answer

#Returning to initial directory
cd $pathmain
clear


#INSTALLING C-BASED MODULE FOR FLOW ROUTING
#main.c is installed as module r.slope.stability.main
#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"raster/r.slope.stability.main ]
then
    rm -rf "$PATHSOURCE"raster/r.slope.stability.main
fi

#Creating directory for installation files and copying r.slope.stability.main.c
mkdir "$PATHSOURCE"raster/r.slope.stability.main
cp r.slope.stability.main.c "$PATHSOURCE"raster/r.slope.stability.main/main.c
cp r.slope.stability.html "$PATHSOURCE"dist.x86_64-unknown-linux-gnu/docs/html/r.slope.stability.main.html

#Moving to the directory for installation files
cd "$PATHSOURCE"raster/r.slope.stability.main

# Creating makefile
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.slope.stability.main" >> Makefile
echo "" >> Makefile
echo "LIBES = \$(GPROJDEP) \$(GISLIB) \$(SEGMENTLIB) \$(RASTERLIB) \$(GMATHLIB)" >> Makefile
echo "DEPENDENCIES = \$(GPROJDEP) \$(GISDEP) \$(GMATHDEP)" >> Makefile
echo "EXTRA_INC = \$(PROJINC)" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Module.make" >> Makefile
echo "" >> Makefile
echo "default: cmd" >> Makefile

# Installing r.slope.stability.main
make
make install

echo ""
echo "Installation of r.slope.stability.main completed. Please check for possible error messages. "
echo "Press ENTER for exit. "
read answer

#Returning to initial directory and terminating sudo mode
cd $pathmain
sudo -k
clear

